@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.5   2015/11/11
+ * Version: 1.8.6   2020/01/01
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -745,8 +745,6 @@ static void make_path_group(void)
 	echo("path_group ANY_PATHNAME \\*:/\\{\\*\\}/");
 	echo("path_group ANY_PATHNAME \\*:/\\{\\*\\}/\\*");
 	echo("path_group ANY_PATHNAME \\*:[\\$]");
-	echo("path_group ANY_PATHNAME "
-	     "socket:[family=\\$:type=\\$:protocol=\\$]");
 	echo("path_group ANY_DIRECTORY /");
 	echo("path_group ANY_DIRECTORY /\\{\\*\\}/");
 	echo("path_group ANY_DIRECTORY \\*:/");
